pub struct Seed { /* private fields */ }Expand description
The secret value used to derive HD wallet addresses from a Mnemonic phrase.
Because it is not possible to create a Mnemonic instance that is invalid, it is
therefore impossible to have a Seed instance that is invalid. This guarantees that only
a valid, intact mnemonic phrase can be used to derive HD wallet addresses.
To get the raw byte value use Seed::as_bytes(). These can be used to derive
HD wallet addresses using another crate (deriving HD wallet addresses is outside the scope of this
crate and the BIP39 standard).
Implementations